QualifierCode

Enum QualifierCode 

pub enum QualifierCode {
    Range8,
    Range16,
    AllObjects,
    Count8,
    Count16,
    CountAndPrefix8,
    CountAndPrefix16,
    FreeFormat16,
}
Application object header types

Variants



Range8

8-bit start stop (value == 0x00)



Range16

16-bit start stop (value == 0x01)



AllObjects

all objects (value == 0x06)



Count8

8-bit count (value == 0x07)



Count16

16-bit count (value == 0x08)



CountAndPrefix8

8-bit count and prefix (value == 0x17)



CountAndPrefix16

16-bit count and prefix (value == 0x28)



FreeFormat16

16-bit free format (value == 0x5B)

Implementations

Source

impl QualifierCode

pub fn from(x: u8) -> Option<Self>

try to create the enum from the underlying value, returning None if the specified value is undefined

pub fn as_u8(self) -> u8

convert the enum to its underlying value