pub enum FileWriteMode {
Write,
Append,
}Expand description
Files can be opened for writing by creating/truncating or appending to an existing file
Variants
Write
Specifies that the file is to be opened for writing. If it already exists, the file is truncated to zero length
Append
Specifies that the file is to be opened for writing, appending to the end of the file