pub struct OpenFile {
pub file_handle: FileHandle,
pub file_size: u32,
pub max_block_size: u16,
}Expand description
The result of opening a file on the outstation
Fields
file_handle: FileHandleThe handle assigned to the file by the outstation
This must be used in subsequent requests to manipulate the file
file_size: u32Size of the file returned by the outstation
max_block_size: u16Maximum block size returned by the outstation
The master must respect this parameter when writing data to a file or the transfer may not succeed