Database

Struct Database 

pub struct Database { /* private fields */ }
Core database implementation shared between an outstation task and the user facing API. This type is always guarded by a DatabaseHandle which provides a transactional API.

Implementations

Source

impl Database

pub fn define_attr( &mut self, prop: AttrProp, attr: OwnedAttribute, ) -> Result<(), AttrDefError>

Define an attribute that will be exposed to the master