OutstationConfig

Struct OutstationConfig 

pub struct OutstationConfig {
Show 16 fields pub outstation_address: EndpointAddress, pub master_address: EndpointAddress, pub event_buffer_config: EventBufferConfig, pub solicited_buffer_size: BufferSize, pub unsolicited_buffer_size: BufferSize, pub rx_buffer_size: BufferSize, pub decode_level: DecodeLevel, pub confirm_timeout: Timeout, pub select_timeout: Timeout, pub features: Features, pub max_unsolicited_retries: Option<usize>, pub unsolicited_retry_delay: Duration, pub keep_alive_timeout: Option<Duration>, pub max_read_request_headers: Option<u16>, pub max_controls_per_request: Option<u16>, pub class_zero: ClassZeroConfig,
}
Outstation configuration parameters

Fields

outstation_address: EndpointAddress

address of the outstation

master_address: EndpointAddress

address of the master with which the outstation will communicate

event_buffer_config: EventBufferConfig

event buffers configuration

solicited_buffer_size: BufferSize

buffer size for transmitted solicited responses

unsolicited_buffer_size: BufferSize

buffer size for transmitted unsolicited responses

rx_buffer_size: BufferSize

buffer size for received requests, i.e. the transport reassembly buffer

decode_level: DecodeLevel

initial decoding level

confirm_timeout: Timeout

confirm timeout for solicited and unsolicited responses

select_timeout: Timeout

timeout after which a matching OPERATE will fail with SELECT_TIMEOUT

features: Features

optional features that can be enabled

max_unsolicited_retries: Option<usize>

number of non-regenerated unsolicited retries to perform

unsolicited_retry_delay: Duration

amount of time to wait after a failed unsolicited response series before starting another series

keep_alive_timeout: Option<Duration>

time without any link activity before the outstation will send REQUEST_LINK_STATES

A value of None will disable this feature

max_read_request_headers: Option<u16>

Maximum number of headers that will be processed in a READ request. Internally, this controls the size of a pre-allocated buffer used to process requests. A minimum value of OutstationConfig::DEFAULT_MAX_READ_REQUEST_HEADERS is always enforced. Requesting more than this number will result in the PARAMETER_ERROR IIN bit being set in the response.

max_controls_per_request: Option<u16>

Maximum number of controls in a single request

class_zero: ClassZeroConfig

controls responses to class 0 READ requests

Implementations

Source

impl OutstationConfig

pub const DEFAULT_MAX_READ_REQUEST_HEADERS: u16 = 64u16

Default number of object headers supported in a READ request

pub const DEFAULT_CONFIRM_TIMEOUT: Duration

Default confirmation timeout

pub const DEFAULT_SELECT_TIMEOUT: Duration

Default select timeout

pub const DEFAULT_UNSOLICITED_RETRY_DELAY: Duration

Default unsolicited retry delay between series

pub fn new( outstation_address: EndpointAddress, master_address: EndpointAddress, event_buffer_config: EventBufferConfig, ) -> Self

constructs an OutstationConfig with default settings, except for the master and outstation link addresses which really don’t have good defaults