TypeCount

Struct TypeCount 

pub struct TypeCount {
    pub num_binary_input: usize,
    pub num_double_bit_binary_input: usize,
    pub num_binary_output_status: usize,
    pub num_counter: usize,
    pub num_frozen_counter: usize,
    pub num_analog: usize,
    pub num_analog_output_status: usize,
    pub num_octet_string: usize,
}
Information about the remaining number of events on a per-type basis

Fields

num_binary_input: usize

number of binary input events remaining in the buffer

num_double_bit_binary_input: usize

number of double-bit binary input events remaining in the buffer

num_binary_output_status: usize

number of binary output status events remaining in the buffer

num_counter: usize

number of counter events remaining in the buffer

num_frozen_counter: usize

number of frozen counter events remaining in the buffer

num_analog: usize

number of analog events remaining in the buffer

num_analog_output_status: usize

number of analog output status events remaining in the buffer

num_octet_string: usize

number octet string events remaining in the buffer