pub struct ServerHandle { /* private fields */ }Expand description
Handle to a running TCP or TLS server. Dropping the handle shuts down the server.
Implementations
Sourceimpl ServerHandle
impl ServerHandle
Sourcepub fn local_addr(&self) -> Option<SocketAddr>
pub fn local_addr(&self) -> Option<SocketAddr>
Returns the local address to which this server is bound.
This can be useful, for example, when binding to port 0 to figure out which port was actually bound.