TlsServerConfig

Struct TlsServerConfig 

pub struct TlsServerConfig { /* private fields */ }
TLS configuration for a server

Implementations

Source

impl TlsServerConfig

pub fn new( client_subject_name: &str, peer_cert_path: &Path, local_cert_path: &Path, private_key_path: &Path, password: Option<&str>, min_tls_version: MinTlsVersion, certificate_mode: CertificateMode, ) -> Result<Self, TlsError>

👎Deprecated since 1.4.1: Please use full_pki or self_signed instead

Legacy method of creating a TLS server configuration

pub fn full_pki( client_subject_name: Option<String>, peer_cert_path: &Path, local_cert_path: &Path, private_key_path: &Path, password: Option<&str>, min_tls_version: MinTlsVersion, ) -> Result<Self, TlsError>

Create a TLS server configuration that expects a full PKI with an authority, and possibly intermediate CA certificates.

If client_subject_name is specified, than the server will verify name is present in the SAN extension or in the Common Name of the client certificate.

If client_subject_name is set to None, then no client name validate is performed, and any authenticated client is allowed.

pub fn self_signed( peer_cert_path: &Path, local_cert_path: &Path, private_key_path: &Path, password: Option<&str>, min_tls_version: MinTlsVersion, ) -> Result<Self, TlsError>

Create a TLS server configuration that expects the client to present a single certificate.

In lieu of performing client subject name validation, the server validates:

  1. That the client presents a single certificate
  2. That the certificate is a byte-for-byte match with the one loaded in peer_cert_path.
  3. That the certificate’s Validity (not before / not after) is currently valid.