#[non_exhaustive]pub enum TaskError {
Show 17 variants
TooManyRequests,
Link(LinkError),
Transport,
RejectedByIin2(Iin),
MalformedResponse(ObjectParseError),
UnexpectedResponseHeaders,
NonFinWithoutCon,
NeverReceivedFir,
UnexpectedFir,
MultiFragmentResponse,
ResponseTimeout,
WriteError,
BadEncoding(BadEncoding),
NoSuchAssociation(EndpointAddress),
NoConnection,
Shutdown,
Disabled,
}Expand description
Errors that can occur while executing a master task
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
TooManyRequests
There are too many user requests queued
Link(LinkError)
An error occurred at the link level
Transport
An error occurred at the transport/app level
RejectedByIin2(Iin)
Outstation returned IIN.2 bit(s) indicating failure
MalformedResponse(ObjectParseError)
A response to the task’s request was malformed
UnexpectedResponseHeaders
The response contains unexpected or invalid headers or data that don’t match the request
NonFinWithoutCon
Non-final response not requesting confirmation
NeverReceivedFir
Received a non-FIR response when expecting the FIR bit
UnexpectedFir
Received FIR bit after already receiving FIR
MultiFragmentResponse
Received a multi-fragmented response when expecting FIR/FIN
ResponseTimeout
The response timed-out
WriteError
Insufficient buffer space to serialize the request or data can’t be encoded
BadEncoding(BadEncoding)
Request data could not be encoded
NoSuchAssociation(EndpointAddress)
The requested association does not exist (not configured)
NoConnection
There is not connection at the transport level
Shutdown
The master was disabled or shutdown
Disabled
The master was disabled