pub struct TypeCount {
pub num_binary_input: usize,
pub num_double_bit_binary_input: usize,
pub num_binary_output_status: usize,
pub num_counter: usize,
pub num_frozen_counter: usize,
pub num_analog: usize,
pub num_analog_output_status: usize,
pub num_octet_string: usize,
}Expand description
Information about the remaining number of events on a per-type basis
Fields
num_binary_input: usizenumber of binary input events remaining in the buffer
num_double_bit_binary_input: usizenumber of double-bit binary input events remaining in the buffer
num_binary_output_status: usizenumber of binary output status events remaining in the buffer
num_counter: usizenumber of counter events remaining in the buffer
num_frozen_counter: usizenumber of frozen counter events remaining in the buffer
num_analog: usizenumber of analog events remaining in the buffer
num_analog_output_status: usizenumber of analog output status events remaining in the buffer
num_octet_string: usizenumber octet string events remaining in the buffer